
/*******************************************************************************
* Copyright (c) 2017 Olivier Langella <olivier.langella@u-psud.fr>.
*
* This file is part of XTPcpp.
*
*     XTPcpp is free software: you can redistribute it and/or modify
*     it under the terms of the GNU General Public License as published by
*     the Free Software Foundation, either version 3 of the License, or
*     (at your option) any later version.
*
*     XTPcpp is distributed in the hope that it will be useful,
*     but WITHOUT ANY WARRANTY; without even the implied warranty of
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*     GNU General Public License for more details.
*
*     You should have received a copy of the GNU General Public License
*     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
*
* Contributors:
*     Olivier Langella <olivier.langella@u-psud.fr> - initial API and implementation
******************************************************************************/
#ifndef PEPTIDETABLEMODEL_H
#define PEPTIDETABLEMODEL_H

#include <QAbstractTableModel>
#include "../../core/project.h"


/** \def PeptideListColumn list of available fields to display in peptide list
 *
 */

enum class PeptideListColumn: std::int8_t {
    checked=0, ///< manual checked
    peptide_grouping_id=1, ///< manual checked
    sample=2,
    scan=3,
    rtmin=4,
    rt=5,
    charge=6,
    sequence=7,
    modifs=8,
    label=9,
    start=10,
    length=11,
    used=12,
    subgroups=13,
    Evalue=14,
    theoretical_mhplus=15,
    delta_mhplus=16,
    hyperscore=17,
    mascot_score=18
};

class PeptideListWindow;

class PeptideTableModel: public QAbstractTableModel
{
    Q_OBJECT
public:
    PeptideTableModel(PeptideListWindow *parent);
    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
    QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;

    static const QString getTitle(PeptideListColumn column);
    static const QString getDescription(PeptideListColumn column);
    static PeptideListColumn getPeptideListColumn(std::int8_t column);

    void setProteinMatch(ProteinMatch * p_protein_match);
    ProteinMatch * getProteinMatch();
signals:
    void peptideEvidenceClicked(PeptideEvidence * p_peptide_evidence);

public slots:
    void onPeptideDataChanged();

private :
    static const QString getTitle(std::int8_t column);
    static const QString getDescription(std::int8_t column);
    static int getColumnWidth(int column);
private :
    ProteinMatch * _p_protein_match= nullptr;
    PeptideListWindow * _p_peptide_list_window=nullptr;
};

#endif // PEPTIDETABLEMODEL_H
